==> gsequencer-3.3.3.tar.gz: gsequencer-3.3.3/ags/audio/fx/ags_fx_analyse_recycling.c <==
/* GSequencer - Advanced GTK Sequencer
 * Copyright (C) 2005-2020 Joël Krähemann
 *
 * This file is part of GSequencer.
 *
 * GSequencer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GSequencer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GSequencer.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <ags/audio/fx/ags_fx_analyse_recycling.h>

#include <ags/audio/fx/ags_fx_analyse_audio_signal.h>

#include <ags/i18n.h>

void ags_fx_analyse_recycling_class_init(AgsFxAnalyseRecyclingClass *fx_analyse_recycling);
void ags_fx_analyse_recycling_init(AgsFxAnalyseRecycling *fx_analyse_recycling);
void ags_fx_analyse_recycling_dispose(GObject *gobject);
void ags_fx_analyse_recycling_finalize(GObject *gobject);

/**
 * SECTION:ags_fx_analyse_recycling
 * @short_description: fx analyse recycling
 * @title: AgsFxAnalyseRecycling
 * @section_id:
 * @include: ags/audio/fx/ags_fx_analyse_recycling.h
 *
 * The #AgsFxAnalyseRecycling class provides ports to the effect processor.
 */

static gpointer ags_fx_analyse_recycling_parent_class = NULL;

static const gchar *ags_fx_analyse_recycling_plugin_name = "ags-fx-analyse";

GType
ags_fx_analyse_recycling_get_type()
{
  static volatile gsize g_define_type_id__volatile = 0;

  if(g_once_init_enter (&g_define_type_id__volatile)){
    GType ags_type_fx_analyse_recycling = 0;

    static const GTypeInfo ags_fx_analyse_recycling_info = {
      sizeof (AgsFxAnalyseRecyclingClass),
      NULL, /* base_init */
      NULL, /* base_finalize */
      (GClassInitFunc) ags_fx_analyse_recycling_class_init,
      NULL, /* class_finalize */
      NULL, /* class_recycling */
      sizeof (AgsFxAnalyseRecycling),
      0,    /* n_preallocs */
      (GInstanceInitFunc) ags_fx_analyse_recycling_init,
    };

    ags_type_fx_analyse_recycling = g_type_register_static(AGS_TYPE_RECALL_RECYCLING,
							   "AgsFxAnalyseRecycling",
							   &ags_fx_analyse_recycling_info,
							   0);

    g_once_init_leave(&g_define_type_id__volatile, ags_type_fx_analyse_recycling);
  }

  return g_define_type_id__volatile;
}

void
ags_fx_analyse_recycling_class_init(AgsFxAnalyseRecyclingClass *fx_analyse_recycling)
{
  GObjectClass *gobject;

  ags_fx_analyse_recycling_parent_class = g_type_class_peek_parent(fx_analyse_recycling);

  /* GObjectClass */
  gobject = (GObjectClass *) fx_analyse_recycling;

  gobject->dispose = ags_fx_analyse_recycling_dispose;
  gobject->finalize = ags_fx_analyse_recycling_finalize;
}

void
ags_fx_analyse_recycling_init(AgsFxAnalyseRecycling *fx_analyse_recycling)
{
  AGS_RECALL(fx_analyse_recycling)->name = "ags-fx-analyse";
  AGS_RECALL(fx_analyse_recycling)->version = AGS_RECALL_DEFAULT_VERSION;
  AGS_RECALL(fx_analyse_recycling)->build_id = AGS_RECALL_DEFAULT_BUILD_ID;
  AGS_RECALL(fx_analyse_recycling)->xml_type = "ags-fx-analyse-recycling";

  AGS_RECALL(fx_analyse_recycling)->child_type = AGS_TYPE_FX_ANALYSE_AUDIO_SIGNAL;
}

void
ags_fx_analyse_recycling_dispose(GObject *gobject)
{
  AgsFxAnalyseRecycling *fx_analyse_recycling;
  
  fx_analyse_recycling = AGS_FX_ANALYSE_RECYCLING(gobject);
  
  /* call parent */
  G_OBJECT_CLASS(ags_fx_analyse_recycling_parent_class)->dispose(gobject);
}

void
ags_fx_analyse_recycling_finalize(GObject *gobject)
{
  AgsFxAnalyseRecycling *fx_analyse_recycling;
  
  fx_analyse_recycling = AGS_FX_ANALYSE_RECYCLING(gobject);

  /* call parent */
  G_OBJECT_CLASS(ags_fx_analyse_recycling_parent_class)->finalize(gobject);
}

/**
 * ags_fx_analyse_recycling_new:
 * @recycling: the #AgsRecycling
 *
 * Create a new instance of #AgsFxAnalyseRecycling
 *
 * Returns: the new #AgsFxAnalyseRecycling
 *
 * Since: 3.3.0
 */
AgsFxAnalyseRecycling*
ags_fx_analyse_recycling_new(AgsRecycling *recycling)
{
  AgsFxAnalyseRecycling *fx_analyse_recycling;

  fx_analyse_recycling = (AgsFxAnalyseRecycling *) g_object_new(AGS_TYPE_FX_ANALYSE_RECYCLING,
								"source", recycling,
								NULL);

  return(fx_analyse_recycling);
}

==> gsequencer_3.18.2.orig.tar.gz: gsequencer-3.18.2/ags/audio/fx/ags_fx_analyse_recycling.c <==
/* GSequencer - Advanced GTK Sequencer
 * Copyright (C) 2005-2020 Joël Krähemann
 *
 * This file is part of GSequencer.
 *
 * GSequencer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GSequencer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GSequencer.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <ags/audio/fx/ags_fx_analyse_recycling.h>

#include <ags/audio/fx/ags_fx_analyse_audio_signal.h>

#include <ags/i18n.h>

void ags_fx_analyse_recycling_class_init(AgsFxAnalyseRecyclingClass *fx_analyse_recycling);
void ags_fx_analyse_recycling_init(AgsFxAnalyseRecycling *fx_analyse_recycling);
void ags_fx_analyse_recycling_dispose(GObject *gobject);
void ags_fx_analyse_recycling_finalize(GObject *gobject);

/**
 * SECTION:ags_fx_analyse_recycling
 * @short_description: fx analyse recycling
 * @title: AgsFxAnalyseRecycling
 * @section_id:
 * @include: ags/audio/fx/ags_fx_analyse_recycling.h
 *
 * The #AgsFxAnalyseRecycling class provides ports to the effect processor.
 */

static gpointer ags_fx_analyse_recycling_parent_class = NULL;

const gchar *ags_fx_analyse_recycling_plugin_name = "ags-fx-analyse";

GType
ags_fx_analyse_recycling_get_type()
{
  static volatile gsize g_define_type_id__volatile = 0;

  if(g_once_init_enter (&g_define_type_id__volatile)){
    GType ags_type_fx_analyse_recycling = 0;

    static const GTypeInfo ags_fx_analyse_recycling_info = {
      sizeof (AgsFxAnalyseRecyclingClass),
      NULL, /* base_init */
      NULL, /* base_finalize */
      (GClassInitFunc) ags_fx_analyse_recycling_class_init,
      NULL, /* class_finalize */
      NULL, /* class_recycling */
      sizeof (AgsFxAnalyseRecycling),
      0,    /* n_preallocs */
      (GInstanceInitFunc) ags_fx_analyse_recycling_init,
    };

    ags_type_fx_analyse_recycling = g_type_register_static(AGS_TYPE_RECALL_RECYCLING,
							   "AgsFxAnalyseRecycling",
							   &ags_fx_analyse_recycling_info,
							   0);

    g_once_init_leave(&g_define_type_id__volatile, ags_type_fx_analyse_recycling);
  }

  return g_define_type_id__volatile;
}

void
ags_fx_analyse_recycling_class_init(AgsFxAnalyseRecyclingClass *fx_analyse_recycling)
{
  GObjectClass *gobject;

  ags_fx_analyse_recycling_parent_class = g_type_class_peek_parent(fx_analyse_recycling);

  /* GObjectClass */
  gobject = (GObjectClass *) fx_analyse_recycling;

  gobject->dispose = ags_fx_analyse_recycling_dispose;
  gobject->finalize = ags_fx_analyse_recycling_finalize;
}

void
ags_fx_analyse_recycling_init(AgsFxAnalyseRecycling *fx_analyse_recycling)
{
  AGS_RECALL(fx_analyse_recycling)->name = "ags-fx-analyse";
  AGS_RECALL(fx_analyse_recycling)->version = AGS_RECALL_DEFAULT_VERSION;
  AGS_RECALL(fx_analyse_recycling)->build_id = AGS_RECALL_DEFAULT_BUILD_ID;
  AGS_RECALL(fx_analyse_recycling)->xml_type = "ags-fx-analyse-recycling";

  AGS_RECALL(fx_analyse_recycling)->child_type = AGS_TYPE_FX_ANALYSE_AUDIO_SIGNAL;
}

void
ags_fx_analyse_recycling_dispose(GObject *gobject)
{
  AgsFxAnalyseRecycling *fx_analyse_recycling;
  
  fx_analyse_recycling = AGS_FX_ANALYSE_RECYCLING(gobject);
  
  /* call parent */
  G_OBJECT_CLASS(ags_fx_analyse_recycling_parent_class)->dispose(gobject);
}

void
ags_fx_analyse_recycling_finalize(GObject *gobject)
{
  AgsFxAnalyseRecycling *fx_analyse_recycling;
  
  fx_analyse_recycling = AGS_FX_ANALYSE_RECYCLING(gobject);

  /* call parent */
  G_OBJECT_CLASS(ags_fx_analyse_recycling_parent_class)->finalize(gobject);
}

/**
 * ags_fx_analyse_recycling_new:
 * @recycling: the #AgsRecycling
 *
 * Create a new instance of #AgsFxAnalyseRecycling
 *
 * Returns: the new #AgsFxAnalyseRecycling
 *
 * Since: 3.3.0
 */
AgsFxAnalyseRecycling*
ags_fx_analyse_recycling_new(AgsRecycling *recycling)
{
  AgsFxAnalyseRecycling *fx_analyse_recycling;

  fx_analyse_recycling = (AgsFxAnalyseRecycling *) g_object_new(AGS_TYPE_FX_ANALYSE_RECYCLING,
								"source", recycling,
								NULL);

  return(fx_analyse_recycling);
}
